﻿
using Microsoft.VisualBasic.FileIO;
using ProjectRouteAgency.Repositories;
using ProjectTourAgency.Enities;
using ProjectTourAgency.Enities.Enums;
using ProjectTourAgency.Implementations;
using ProjectTourAgency.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectTourAgency.Forms
{
    public partial class FormClient : Form
    {
        private readonly IClientRepository _clientRepository;

        private int? _clientId;
        public int Id
        {
            set
            {
                try
                {
                    var client = _clientRepository.ReadClientById(value);
                    if (client == null)
                    {
                        throw new InvalidOperationException(nameof(client));
                    }
                    textBoxName.Text = client.FullName;
                    textBoxNumber.Text = client.PhoneNumber;
                    textBoxMoney.Text = client.Money.ToString();
                    dateTimePickerDate.Value = client.BirthDate;
                    foreach (ClientStatus elem in
Enum.GetValues(typeof(ClientStatus)))
                    {
                        if ((elem & client.ClientStatus) != 0)
                        {
                            checkedListBoxClientStatus.SetItemChecked(checkedListBoxClientStatus.Items.IndexOf(
                            elem), true);
                        }
                    }

                    _clientId = value;
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении ланных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public FormClient(IClientRepository clientRepository)
        {
            InitializeComponent();
            _clientRepository = clientRepository ??
                throw new ArgumentNullException(nameof(clientRepository));
            foreach (var elem in Enum.GetValues(typeof(ClientStatus)))
            {
                checkedListBoxClientStatus.Items.Add(elem);
            }

        }

        private void buttonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxName.Text) ||
                        string.IsNullOrWhiteSpace(textBoxNumber.Text)
                        || string.IsNullOrWhiteSpace(textBoxMoney.Text) || string.IsNullOrWhiteSpace(dateTimePickerDate.Text)
                           || checkedListBoxClientStatus.CheckedItems.Count == 0)
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_clientId.HasValue)
                {
                    _clientRepository.UpdateClient(CreateClient(_clientId.Value));
                }
                else
                {
                    _clientRepository.CreateClient(CreateClient(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void buttonCancel_Click(object sender, EventArgs e) => Close();

        private Client CreateClient(int id)
        {
            ClientStatus clientStatus = ClientStatus.None;
            foreach (var elem in checkedListBoxClientStatus.CheckedItems)
            {
                clientStatus |= (ClientStatus)elem;
            }
            return Client.CreateEntity(id, textBoxName.Text, dateTimePickerDate.Value, textBoxNumber.Text,
                int.Parse(textBoxMoney.Text), clientStatus);
            

        }
    }
}
