﻿using ProjectEmployeeAgency.Repositories;
using ProjectRouteAgency.Repositories;
using ProjectTourAgency.Enities;
using ProjectTourAgency.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectTourAgency.Forms
{
    public partial class FormClientTour : Form
    {
        private readonly ITourRepository _tourRepository;
        public FormClientTour(ITourRepository tourRepository,
            IEmployeeRepository employeeRepository,
            IRouteRepository routeRepository, IClientRepository clientRepository)
        {
            InitializeComponent();
            _tourRepository = tourRepository ??
                throw new ArgumentNullException(nameof(tourRepository));
            comboBoxEmployeeId.DataSource = employeeRepository.ReadEmployees();
            comboBoxEmployeeId.DisplayMember = "FullName";
            comboBoxEmployeeId.ValueMember = "Id";

            comboBoxRouteId.DataSource = routeRepository.ReadRoutes();
            comboBoxRouteId.DisplayMember = "Destination";
            comboBoxRouteId.ValueMember = "Id";

            ColumnClient.DataSource = clientRepository.ReadClients();
            ColumnClient.DisplayMember = "FullName";
            ColumnClient.ValueMember = "Id";
        }

        private void dataGridView_CellContentClick(object sender, DataGridViewCellEventArgs e)
        {

        }

        private void buttonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (dataGridView.RowCount < 1
                    || comboBoxEmployeeId.SelectedIndex < 0
                    || comboBoxRouteId.SelectedIndex < 0)
                {
                    throw new Exception("Есть незаполненные поля");
                }
                _tourRepository.CreateTour(Tour.CreateEntity(0, comboBoxEmployeeId.SelectedIndex,
                    comboBoxRouteId.SelectedIndex, dateTimePicker.Value,CreateListClientTourFromDataGrid()));
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void buttonCancel_Click(object sender, EventArgs e) => Close();

        private List<ClientTour> CreateListClientTourFromDataGrid()
        {
            var list = new List<ClientTour>();
            foreach(DataGridViewRow row in dataGridView.Rows)
            {
                if (row.Cells["ColumnClient"].Value == null 
                    || row.Cells["ColumnCost"].Value == null)
                {
                    continue;
                }
                list.Add(ClientTour.CreateEntity(0, Convert.ToInt32(row.Cells["ColumnClient"].Value), 0,
                    Convert.ToInt32(row.Cells["ColumnCost"].Value)));
            }
            return list;
        }

    }
}
