﻿
using ProjectEmployeeAgency.Repositories;
using ProjectRouteAgency.Repositories;
using ProjectTourAgency.Enities;
using ProjectTourAgency.Enities.Enums;
using ProjectTourAgency.Implementations;
using ProjectTourAgency.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectTourAgency.Forms
{
    public partial class FormEmployee: Form
    {
        private readonly IEmployeeRepository _employeeRepository;

        private int? _employeeId;
        public int Id
        {
            set
            {
                try
                {
                    var employee = _employeeRepository.ReadEmployeeById(value);
                    if (employee == null)
                    {
                        throw new InvalidOperationException(nameof(employee));
                    }
                    textBoxName.Text = employee.FullName;
                    comboBoxJob.SelectedItem = employee.EmployeeJob;
                    _employeeId = value;
                    
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении ланных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public FormEmployee(IEmployeeRepository employeeRepository)
        {
            InitializeComponent();
            _employeeRepository = employeeRepository ??
                throw new ArgumentNullException(nameof(employeeRepository));
            comboBoxJob.DataSource = Enum.GetValues(typeof(EmpoyeeJob));

        }

        private void buttonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxName.Text) ||
                        string.IsNullOrWhiteSpace(comboBoxJob.Text))
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_employeeId.HasValue)
                {
                    _employeeRepository.UpdateEmployee(CreateEmployee(_employeeId.Value));
                }
                else
                {
                    _employeeRepository.CreateEmployee(CreateEmployee(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void buttonCancel_Click(object sender, EventArgs e) => Close();

        private Employee CreateEmployee(int id) => Employee.CreateEntity(id, textBoxName.Text, (Enities.Enums.EmpoyeeJob)comboBoxJob.SelectedItem!);
    }
}
