﻿
using ProjectRouteAgency.Repositories;
using ProjectTourAgency.Enities;
using ProjectTourAgency.Implementations;
using ProjectTourAgency.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectTourAgency.Forms
{
    public partial class FormRoute : Form
    {
        private readonly IRouteRepository _routeRepository;

        private int? _routeId;
        public int Id
        {
            set
            {
                try
                {
                    var route = _routeRepository.ReadRouteById(value);
                    if (route == null)
                    {
                        throw new InvalidOperationException(nameof(route));
                    }
                    textBoxDestination.Text = route.Destination;
                    textBoxDeparture.Text = route.Departure;
                    textBoxDuration.Text = route.Duration.ToString();
                    _routeId = value;
                    
                } 
                catch(Exception ex)
                {
                    MessageBox.Show(ex.Message,"Ошибка при получении ланных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public FormRoute(IRouteRepository routeRepository, ITourRepository tourRepository)
        {
            InitializeComponent();
            _routeRepository = routeRepository ?? 
                throw new ArgumentNullException(nameof(routeRepository));
           

        }

        private void buttonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxDestination.Text) ||
                        string.IsNullOrWhiteSpace(textBoxDeparture.Text) || string.IsNullOrWhiteSpace(textBoxDuration.Text)
                        || string.IsNullOrWhiteSpace(textBoxPrice.Text) || string.IsNullOrWhiteSpace(dateTimePickerDepartureDate.Text))
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_routeId.HasValue)
                {
                    _routeRepository.UpdateRoute(CreateRoute(_routeId.Value));
                }
                else
                {
                    _routeRepository.CreateRoute(CreateRoute(0));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void buttonCancel_Click(object sender, EventArgs e) => Close();

        private Route CreateRoute(int id) => Route.CreateEntity(id, textBoxDestination.Text,
            textBoxDeparture.Text, int.Parse(textBoxDuration.Text));
    }
}
