﻿
using ProjectRouteAgency.Repositories;
using ProjectTourAgency.Enities;
using ProjectTourAgency.Implementations;
using ProjectTourAgency.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectTourAgency.Forms
{
    public partial class FormClient : Form
    {
        private readonly IClientRepository _clientRepository;

        private int? _clientId;
        public int Id
        {
            set
            {
                try
                {
                    var client = _clientRepository.ReadClientById(value);
                    if (client == null)
                    {
                        throw new InvalidOperationException(nameof(client));
                    }
                    textBoxName.Text = client.FullName;
                    textBoxNumber.Text = client.PhoneNumber;
                    textBoxMoney.Text = client.Money.ToString();
                    dateTimePickerDate.Value = client.BirthDate;

                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Ошибка при получении ланных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }
        }

        public FormClient(IClientRepository clientRepository)
        {
            InitializeComponent();
            _clientRepository = clientRepository ??
                throw new ArgumentNullException(nameof(clientRepository));

        }

        private void buttonSave_Click(object sender, EventArgs e)
        {
            try
            {
                if (string.IsNullOrWhiteSpace(textBoxName.Text) ||
                        string.IsNullOrWhiteSpace(textBoxNumber.Text)
                        || string.IsNullOrWhiteSpace(textBoxMoney.Text) || string.IsNullOrWhiteSpace(dateTimePickerDate.Text))
                {
                    throw new Exception("Имеются незаполненные поля");
                }

                if (_clientId.HasValue)
                {
                    _clientRepository.UpdateClient(CreateClient(_clientId.Value));
                }
                else
                {
                    _clientRepository.CreateClient(CreateClient(_clientId.Value));
                }
                Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при сохранении", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

        private void buttonCancel_Click(object sender, EventArgs e) => Close();

        private Client CreateClient(int id) => Client.CreateEntity(id, textBoxName.Text, dateTimePickerDate.Value,textBoxNumber.Text, Convert.ToInt32(textBoxMoney.Text));
    }
}
